//
//  SavedGame.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/5/24.
//

import SwiftUI

struct UserSavedGame: Identifiable, Codable {
    let id: String
    let name: String
    let minPlayers: Int
    let maxPlayers: Int
    let minPlaytime: Int
    let maxPlaytime: Int
    let thumbnailURL: String
    let image: String
    let description: String
    let publishedYear: String
    let userID: String

  init(game: BoardGame, userID: String) {
    self.id = UUID().uuidString
    self.name = game.name
    self.minPlayers = game.info?.minPlayers ?? 0
    self.maxPlayers = game.info?.maxPlayers ?? 0
    self.minPlaytime = game.info?.minPlaytime ?? 0
    self.maxPlaytime = game.info?.maxPlaytime ?? 0
    self.thumbnailURL = game.info?.thumbnail ?? ""
    self.image = game.info?.image ?? ""
    self.description = game.info?.description ?? ""
    self.publishedYear = game.info?.publishedYear ?? ""
    self.userID = userID
  }

  enum CodingKeys: CodingKey {
    case name
    case id
    case thumbnailURL
    case userID
    case minPlayers
    case maxPlayers
    case minPlaytime
    case maxPlaytime
    case image
    case description
    case publishedYear
  }
}

