//
//  DiceView.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/5/24.
//

import SwiftUI

struct DiceView: View {
    
    @State var number = 1
    @State private var selectedDice = "d20"
    
    @State private var isSpinning = false

    let diceOptions = ["d6", "d8", "d10", "d12", "d20"]
    
    var body: some View {
        NavigationStack{
            VStack {
                HStack {
                    Text("Which die would you like to roll?")
                    Spacer()
                    Picker("Dice:", selection: $selectedDice) {
                        ForEach(diceOptions, id: \.self) { option in
                            Text(option)
                        }
                    }
                }
                Spacer()
                Text("You rolled a **\(number)**!")
                    .padding()
                    .font(.title2)
                
                Image("\(selectedDice).\(number)")
                    .resizable()
                    .scaledToFit()
                    .foregroundStyle(.tint)
                    .padding()
                    .rotationEffect(.degrees(isSpinning ? 360 : 0), anchor: .center)
                    .animation(isSpinning ? Animation.linear(duration: 2.5).speed(5) : .none)
                
                Button(action: {
                    isSpinning.toggle()
                    DispatchQueue.main.async {
                        self.isSpinning.toggle()
                    }
                    
                    if selectedDice == "d6" {
                        number = Int.random(in:1...6)
                    }
                    if selectedDice == "d8" {
                        number = Int.random(in:1...8)
                    }
                    if selectedDice == "d10" {
                        number = Int.random(in:1...10)
                    }
                    if selectedDice == "d12" {
                        number = Int.random(in:1...12)
                    }
                    if selectedDice == "d20" {
                        number = Int.random(in:1...20)
                    }
                }){
                    Text("Roll")
                }
                .padding()
                .background(Color("nd-purple"))
                .clipShape(Capsule())
                .foregroundColor(.white)
                .font(.title)
                .fontWeight(.bold)
                
                Spacer()
            }
            .padding()
            .navigationTitle("Dice Roller")

        }
    }
}

struct NavigationBarTitleModifier: ViewModifier {
  func body(content: Content) -> some View {
    content
      .font(.title)
        .fontWeight(.bold)
        .frame(maxWidth: .infinity, alignment: .leading)
  }
}

extension Text {
  func navigationBarTitleStyle() -> some View {
    modifier(NavigationBarTitleModifier())
  }
}


#Preview {
    DiceView()
}
