//
//  LoginView.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 10/10/23.
//

import SwiftUI
import PhotosUI
import Firebase
import FirebaseFirestore
import FirebaseStorage

struct LoginView: View {
    @State var emailID: String = ""
    @State var password: String = ""
    @State var createAccount: Bool = false
    @State var showError: Bool = false
    @State var errorMessage: String = ""
    @State var isLoading: Bool = false
    @AppStorage("log_status") var logStatus: Bool = false
    @AppStorage("user_profile_url") var profileURL: URL?
    @AppStorage("user_name") var userNameStored: String = ""
    @AppStorage("user_UID") var userUID: String = ""
    var body: some View {
        VStack(spacing: 10) {
            Text("Welcome to No Dice")
                .font(.largeTitle.bold())
                .vAlign(.center)
            
            Image("nd-pips-hd")
                .resizable()
                .scaledToFit()
            
            Text("Let's Sign In")
                .font(.largeTitle.bold())
                .vAlign(.center)
                
            VStack(spacing: 12){
                TextField("Email", text: $emailID)
                    .textContentType(.emailAddress)
                    .border(1, .gray.opacity(0.5))
                    .padding(.top,25)
                
                SecureField("Password", text: $password)
                    .textContentType(.emailAddress)
                    .border(1, .gray.opacity(0.5))
                
                Button("Reset Password?", action: resetPassword)
                    .font(.callout)
                    .hAlign(.trailing)
                
                Button(action: loginUser) {
                    Text("Log In")
                        .foregroundColor(.white)
                        .fillView(.black)
                        .hAlign(.center)
                }
            }
            .padding(.horizontal, 20)
            .vAlign(.center)
            
            HStack{
                Text("Don't have an account?")
                
                Button("Register Now"){
                    createAccount.toggle()
                }
                .fontWeight(.bold)
                .foregroundColor(.black)
            }
            .vAlign(.bottom)
            .padding(15)
            
            .fullScreenCover(isPresented: $createAccount) {
                RegisterView()
            }
            .alert(errorMessage, isPresented: $showError, actions: {})
        }
        .overlay(content: {
            LoadingView(show: $isLoading)
        })
    }
    func loginUser(){
        isLoading = true
        closeKeyboard()
        Task{
            do{
                try await Auth.auth().signIn(withEmail: emailID, password: password)
                print("User Found")
                try await fetchUser()
            }catch{
                await setError(error)
            }
        }
    }
    
    func fetchUser()async  throws{
        guard let userID = Auth.auth().currentUser?.uid else{return}
        let user = try await Firestore.firestore().collection("Users").document(userID).getDocument(as: User.self)
        await MainActor.run(body: {
            userUID = userID
            userNameStored = user.username
            profileURL = user.userProfileURL
            logStatus = true
        })
    }
    
    func resetPassword(){
        Task{
            do{
                try await Auth.auth().sendPasswordReset(withEmail: emailID)
                print("Link Sent")
            }catch{
                await setError(error)
            }
        }
    }
    
    func setError(_ error: Error)async{
        await MainActor.run(body: {
            errorMessage = error.localizedDescription
            showError.toggle()
            isLoading = false
        })
    }
}

//Where RegisterView() used to be


//#Preview {
  //  LoginView()
//}

//Where extensions used to be

