//
//  CreateNewPost.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/5/24.
//

import SwiftUI
import PhotosUI
import Firebase
import FirebaseStorage

struct CreateNewPost: View {
    
    var onPost: (Post)->()
    @State private var postText: String = ""
    @State private var postImageData: Data?
    @State var postGameInformation: Data?
    @State private var postGameNameSpelled: String = ""
    @State private var postRating: String = "0"
    @State private var postPlayersPicked: String = "1"
    @State private var postTimePicked: String = "15 Minutes"
    @AppStorage("user_profile_url") private var profileURL: URL?
    @AppStorage("user_name") private var userName: String = ""
    @AppStorage("user_UID") private var userUID: String = ""
    @Environment(\.dismiss) private var dismiss
    @State private var isLoading: Bool = false
    @State private var errorMessage: String = ""
    @State private var showError: Bool = false
    @FocusState private var showKeyboard: Bool
    
    @State private var selectedGameID: String?
    @ObservedObject var viewModel = SavedGamesViewModel()
    @State private var showingSelectionView = false
    @State private var selectedGame: UserSavedGame?
    
    var body: some View {
        NavigationView {
            VStack{
                HStack{
                    Menu{
                        Button("Cancel",role: .destructive){
                            dismiss()
                        }
                    } label: {
                        Text("Cancel")
                            .font(.callout)
                            .foregroundColor(.black)
                    }
                    .hAlign(.leading)
                    
                    Text("New Post")
                        .font(.callout)
                        .foregroundColor(.black)
                        .fontWeight(.bold)
                        .hAlign(.center)
                    
                    Button(action: createPost) {
                        Text("Post")
                            .font(.callout)
                            .fontWeight(.bold)
                            .foregroundColor(Color("nd-green"))
                            .padding(.horizontal, 20)
                            .padding(.vertical, 6)
                    }
                    .disableWithOpacity(postText == "")
                    .hAlign(.trailing)
                    
                }
                .padding(.horizontal, 15)
                .padding(.vertical, 10)
                .background {
                    Rectangle()
                        .fill(.gray.opacity(0.05))
                        .ignoresSafeArea()
                }
                
                ScrollView(.vertical, showsIndicators: false) {
                    VStack(spacing: 15){
                        
                        VStack(spacing: 12){
                            Text("Game")
                            //.padding(.horizontal)
                                .hAlign(.leading)
                                .font(.title2)
                                .fontWeight(.bold)
                            
                            Button("Select Game") {
                                self.showingSelectionView = true
                            }
                            .sheet(isPresented: $showingSelectionView) {
                                GameSelectionView(savedGames: viewModel.savedGames, currentSelection: selectedGame?.id, onSelect: { game in
                                    self.selectedGame = game
                                    print("Game selected: \(game.name)")
                                })
                            }
                            
                            if let selectedGame = selectedGame {
                                        Text("Selected Game: \(selectedGame.name)")
                            }
                            
                            
                                
                            
                            //TextField("Game Name Here", text: $postGameNameSpelled, axis: .vertical)
                                //.focused($showKeyboard)
                            
                            //if postGameInformation == nil {
                            //    NavigationLink(destination: GameLibraryView()){
                            //        HStack{
                            //            Text("Add a Game")
                            //                .fontWeight(.bold)
                            //                .font(.title3)
                            //
                            //            Spacer()
                            //
                            //            Image(systemName: "plus.magnifyingglass")
                            //                .fontWeight(.bold)
                            //                .font(.title3)
                            //
                            //        }
                            //        .padding(.vertical, 15)
                            //    }
                            //
                            //}else{
                            //    HStack{
                            //        Image("star5")
                            //            .resizable()
                            //            .scaledToFit()
                            //            .frame(width: 80, height: 80)
                            //
                            //        Text("Text")
                            //            .fontWeight(.bold)
                            //            .font(.title3)
                            //    }
                            //    .hAlign(.leading)
                            //    .border(1, .gray.opacity(0.5))
                            //
                            //}
                        }
                        
                        
                        VStack(spacing: 12){
                            Text("Overall Rating")
                            //.padding(.horizontal)
                                .hAlign(.leading)
                                .font(.title2)
                                .fontWeight(.bold)
                            
                            HStack {
                                Picker("Overall Rating",
                                       selection: $postRating) {
                                    Text("0 Stars")
                                        .tag("0")
                                    
                                    Text("1 Star")
                                        .tag("1")
                                    
                                    Text("2 Stars")
                                        .tag("2")
                                    
                                    Text("3 Stars")
                                        .tag("3")
                                    
                                    Text("4 Stars")
                                        .tag("4")
                                    
                                    Text("5 Stars")
                                        .tag("5")
                                }
                                //.padding(.horizontal)
                                
                                Spacer()
                                
                                Image("star\(postRating)")
                                    .resizable()
                                    .scaledToFit()
                                    .frame(width: 150)
                                    .padding(.horizontal)
                            }
                        }
                        
                        VStack(spacing: 12){
                            Text("Number of Players")
                            //.padding(.horizontal)
                                .hAlign(.leading)
                                .font(.title2)
                                .fontWeight(.bold)
                            
                            HStack {
                                Picker("Number of Players",
                                       selection: $postPlayersPicked) {
                                    Text("1")
                                        .tag("1")
                                    Text("2")
                                        .tag("2")
                                    Text("3")
                                        .tag("3")
                                    Text("4")
                                        .tag("4")
                                    Text("5")
                                        .tag("5")
                                    Text("6")
                                        .tag("6")
                                    Text("7")
                                        .tag("7")
                                    Text("8")
                                        .tag("8")
                                    Text("9")
                                        .tag("9")
                                    Text("10+")
                                        .tag("10+")
                                }
                                //.padding(.horizontal)
                                
                                Spacer()
                            }
                        }
                        
                        VStack(spacing: 12){
                            Text("Estimated Play Time")
                            //.padding(.horizontal)
                                .hAlign(.leading)
                                .font(.title2)
                                .fontWeight(.bold)
                            
                            HStack {
                                Picker("Game Duration",
                                       selection: $postTimePicked) {
                                    Text("15 Minutes")
                                        .tag("15 Minutes")
                                    Text("30 Minutes")
                                        .tag("30 Minutes")
                                    Text("45 Minutes")
                                        .tag("45 Minutes")
                                    Text("1 Hour")
                                        .tag("1 Hour")
                                    Text("1 Hour 15 Minutes")
                                        .tag("1 Hour 15 Minutes")
                                    Text("1 Hour 30 Minutes")
                                        .tag("1 Hour 30 Minutes")
                                    Text("1 Hour 45 Minutes")
                                        .tag("1 Hour 45 Minutes")
                                    Text("2 Hours")
                                        .tag("2 Hours")
                                    Text("2 Hours 15 Minutes")
                                        .tag("2 Hours 15 Minutes")
                                    Text("2 Hours 30 Minutes")
                                        .tag("2 Hours 30 Minutes")
                                    Text("2 Hours 45 Minutes")
                                        .tag("2 Hours 45 Minutes")
                                    Text("3+ Hours")
                                        .tag("3+ Hours")
                                    
                                }
                                //.padding(.horizontal)
                                
                                Spacer()
                            }
                        }
                        
                        VStack(spacing: 12){
                            Text("Your Review")
                            //.padding(.horizontal)
                                .hAlign(.leading)
                                .font(.title2)
                                .fontWeight(.bold)
                            
                            TextField("Jot your thoughts down here", text:$postText, axis: .vertical)
                                .focused($showKeyboard)
                            
                            if let postImageData, let image = UIImage(data: postImageData){
                                GeometryReader{
                                    let size = $0.size
                                    Image(uiImage: image)
                                        .resizable()
                                        .aspectRatio(contentMode: .fill)
                                        .frame(width: size.width, height: size.height)
                                        .clipShape(RoundedRectangle(cornerRadius: 10, style: .continuous))
                                }
                            }
                        }
                    }
                    .padding(15)
                }
                
                if showKeyboard == true{
                    Divider()
                    
                    HStack{
                        Button("Done"){
                            showKeyboard = false
                        }
                        .hAlign(.trailing)
                    }
                    .foregroundColor(.black)
                    .padding(.horizontal, 15)
                    .padding(.vertical, 10)
                    
                }else{
                    Divider()
                }
            }
            .vAlign(.top)
            .alert(errorMessage, isPresented: $showError, actions: {})
            .overlay{
                LoadingView(show: $isLoading)
            }
            .onAppear {
                viewModel.fetchSavedGames(userID: userUID)
            }
        }
    }
    
    func createPost() {
        
        guard let selectedGame = selectedGame else {
                print("No game selected or game not found")
                return
        }
        
        isLoading = true
        showKeyboard = false
        Task{
            do{
                guard let profileURL = profileURL else{return}
                let post = Post(text: postText, imageReferenceID: selectedGame.image, gameNameSpelled: selectedGame.name, rating: postRating, playersPicked: postPlayersPicked, timePicked: postTimePicked, userName: userName, userUID: userUID, userProfileURL: profileURL)
                try await createDocumentAtFirebase(post)
                print("Creating post with game: \(selectedGame.name)")
            }catch{
                await setError(error)
            }
        }
    }
    
    func createDocumentAtFirebase(_ post: Post)async throws{
        let doc = Firestore.firestore().collection("Posts").document()
        let _ = try doc.setData(from: post, completion: { error in
            if error == nil{
                isLoading = false
                var updatedPost = post
                updatedPost.id = doc.documentID
                onPost(updatedPost)
                dismiss()
            }
        })
    }
    
    func setError(_ error: Error)async{
        await MainActor.run(body: {
            errorMessage = error.localizedDescription
            showError.toggle()
        })
    }
}

