//
//  PostsView.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/8/24.
//

import SwiftUI

struct PostsView: View {
    @State private var recentPosts: [Post] = []
    @State private var createNewPost: Bool = false
    
    var body: some View {
        NavigationStack{
            ReusablePostsView(posts: $recentPosts)
                .hAlign(.center)
                .vAlign(.center)
                .overlay(alignment: .bottomTrailing) {
                    Button{
                        createNewPost.toggle()
                    }label: {
                        Image(systemName: "plus")
                            .font(.title)
                            .fontWeight(.semibold)
                            .foregroundColor(.white)
                            .padding(10)
                            .background(Color("nd-purple"), in: Circle())
                    }
                    .padding(15)
                }
                .toolbar(content: {
                    ToolbarItem(placement: .navigationBarTrailing) {
                        NavigationLink{
                            SearchUserView()
                        } label: {
                            Image(systemName: "magnifyingglass")
                                .tint(.black)
                                .scaleEffect(1.1)
                        }
                    }
                })
                .navigationTitle("Main Feed")
        }
        .fullScreenCover(isPresented: $createNewPost) {
                CreateNewPost { post in
                    recentPosts.insert(post, at: 0)
            }
        }
    }
}

#Preview {
    PostsView()
}
