//
//  ProfileGamesView.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/8/24.
//

import SwiftUI
import Foundation
import Firebase
import FirebaseFirestore
import FirebaseFirestoreSwift

class SavedGamesViewModel: ObservableObject {
    @Published var savedGames = [UserSavedGame]()

    private var db = Firestore.firestore()

    func fetchSavedGames(userID: String) {
        db.collection("Users").document(userID).collection("savedGames")
            .addSnapshotListener { (querySnapshot, error) in
                guard let documents = querySnapshot?.documents else {
                    print("No documents or error: \(error?.localizedDescription ?? "Unknown error")")
                    return
                }

                let games = documents.compactMap { queryDocumentSnapshot in
                    try? queryDocumentSnapshot.data(as: UserSavedGame.self)
                }
                print("Fetched games: \(games)")
                self.savedGames = games
            }
    }
}

struct ProfileGamesView: View {
    
    @ObservedObject var viewModel = SavedGamesViewModel()
    
    var userID: String
    
    var body: some View {
        List(viewModel.savedGames) { game in
            VStack(alignment: .leading) {
                Text(game.name)
                    .fontWeight(.bold)
                Text("Players: \(game.minPlayers)-\(game.maxPlayers)")
                Text("Playtime: \(game.minPlaytime)-\(game.maxPlaytime) minutes")
            }
        }
        .onAppear {
            viewModel.fetchSavedGames(userID: userID)
        }
    }
}
