//
//  ReusableProfileContentReal.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/8/24.
//

import SwiftUI
import SDWebImageSwiftUI

struct ReusableProfileContentReal: View {
    
    var user: User
    @State private var fetchedPosts: [Post] = []
    
    var body: some View {
        ScrollView(.vertical, showsIndicators: false){
            LazyVStack{
                HStack(spacing: 12){
                    WebImage(url: user.userProfileURL) { image in
                        image.resizable()
                    } placeholder: {
                        Image("NullProfile")
                            .resizable()
                    }
                    .aspectRatio(contentMode: .fill)
                    .frame(width: 100, height: 100)
                    .clipShape(Circle())
                    
                    VStack(alignment: .leading, spacing: 6){
                        Text(user.username)
                            .font(.title3)
                            .fontWeight(.bold)
                        
                        Text(user.userBio)
                            .font(.caption)
                            .foregroundColor(.gray)
                            .lineLimit(3)
                        
                        if let bioLink = URL(string: user.userBioLink) {
                            Link(user.userBioLink, destination: bioLink)
                                .font(.callout)
                                .tint(Color("nd-purple"))
                                .lineLimit(1)
                        }
                    }
                    .hAlign(.leading)
                }
                .padding()
                
                HStack{
                    Button{
                        //
                    }label: {
                        HStack{
                            Text("Posts")
                                .font(.title2)
                                .fontWeight(.bold)
                                .foregroundColor(.black)
                                //.hAlign(.leading)
                            
                            Image(systemName: "rectangle.portrait.on.rectangle.portrait.angled.fill")
                                .font(.title2)
                                .foregroundColor(Color("nd-purple"))
                        }
                        .padding()
                        .hAlign(.leading)
                    }
                }
                
                ReusablePostsView(basedOnUID: true, uid: user.userUID, posts: $fetchedPosts)
            }
        }
    }
}
