//
//  SavedGameItemDetailView.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/8/24.
//

import SwiftUI

struct SavedGameItemDetailView: View {
    
    let game: UserSavedGame
    @State private var isSaved: Bool = false
    @State private var thumbnailImage: UIImage? = nil
    
    var body: some View {

        VStack {
            AsyncImage(url: URL(string: game.image)) { phase in
                  if let image = phase.image {
                    image
                      .resizable()
                      .scaledToFit()
                      .frame(width: 200, height: 200)
                      .padding(.top, -50)
                      .aspectRatio(contentMode: .fit)
                  } else if phase.error != nil {
                    Text("Error loading image")
                  } else {
                    ProgressView()
                  }
                }
            }
            HStack {
                Text("\(game.name) (\(game.publishedYear))")
                    .font(.title)
                    .fontWeight(.bold)
                    .padding(.horizontal)
                    .padding(.bottom)
                    .padding(.top)
                Spacer()
            }
            
            ScrollView(showsIndicators: true) {
                
            HStack {
                if game.minPlayers == game.maxPlayers {
                    Text("Players: \(game.minPlayers)")
                } else {
                    Text("Players: \(game.minPlayers)-\(game.maxPlayers)")
                }
                Spacer()
            }
            .font(.title3)
            .fontWeight(.semibold)
            .padding(.horizontal)
            .padding(.bottom)
            
            HStack {
                if game.minPlaytime == game.maxPlaytime {
                    Text("Play Time: \(game.minPlaytime) min")
                } else {
                    Text("Play Time: \(game.minPlaytime)-\(game.maxPlaytime) min")
                }
                
                Spacer()
            }
            .font(.title3)
            .fontWeight(.semibold)
            .padding(.horizontal)
            .padding(.bottom)
            
            Text("\(processDescription(game.description))")
                .padding(.horizontal)
            }

    }
                 
                 func processDescription(_ description: String) -> String {
                     return description.replacingOccurrences(of: "<br/>", with: "\n")
                         .replacingOccurrences(of: "&mdash;", with: "-")
                         .replacingOccurrences(of: "&quot;", with: "'")
                         .replacingOccurrences(of: "&amp;", with: "&")
                         .replacingOccurrences(of: "&ndash;", with: "-")
                         .replacingOccurrences(of: "&nbsp;", with: " ")

                 }
}

