//
//  SavedGameListItemView.swift
//  NoDiceAlpha
//
//  Created by Ben Albright on 4/8/24.
//

import SwiftUI

struct SavedGameListItemView: View {
    
    let game: UserSavedGame
    @State private var thumbnailImage: UIImage? = nil
    
    var body: some View {
        NavigationLink(destination: SavedGameItemDetailView(game: game)) {
            HStack {
                AsyncImage(url: URL(string: game.thumbnailURL)) { phase in
                      if let image = phase.image {
                        image
                          .resizable()
                          .scaledToFit()
                          .frame(width: 100, height: 100)
                      } else if phase.error != nil {
                        Text("Error loading image")
                      } else {
                        ProgressView()
                      }
                    }
                VStack(alignment: .leading) {
                    Text("\(game.name) (\(game.publishedYear))")
                        .font(.headline)
                        .fontWeight(.bold)
                    HStack {
                        
                        if game.minPlayers == game.maxPlayers {
                            Text("Players: \(game.minPlayers)")
                        } else {
                            Text("Players: \(game.minPlayers)-\(game.maxPlayers)")
                        }
                        
                        Spacer()
                        
                        if game.minPlaytime == game.maxPlaytime {
                            Text("Play Time: \(game.minPlaytime) min")
                        } else {
                            Text("Play Time: \(game.minPlaytime)-\(game.maxPlaytime) min")
                        }
                        
                        Spacer()
                    }
                    .font(.subheadline)
                    .foregroundColor(.gray)
                }
            }
        }
    }
}
